﻿using Sig.DeviceAPI;
using Sig.SignAPI;
using System;
using System.IO;
using System.Threading.Tasks;
using static System.Console;

namespace ViewDocWithPad
{
    class Program
    {

        static async Task Main(string[] arg)
        {
            Driver driver = Driver.FromCommunicationType(Sig.DeviceCom.CommunicationType.USB);

            _ = driver.EnumerateDevices(out string[] devices, out _, FilterDeviceKind.dkStepOver);

            if (devices is null || 0 == devices.Length)
            {
                Error("No device found.");
                return;
            }

            _ = driver.SetDevice(devices[0]);
            driver.ButtonEvent += OnButtonEvent;

            // The SignAPI requires a running PDF service.
            // See https://www.stepoverinfo.net/confluence/x/owS-Aw 
            byte[] document = await GetDocument();
            ISigning signing = await SigningFactory.StartAsync(driver, document);
            if (signing is null)
            {
                Error("Failed. Is the PDF service running?");
                return;
            }

            bool success = await signing.ViewDocumentAsync(0, Sig.SignAPI.Zoom.Level.FitWidth, true);
            if (!success)
            {
                Error("Failed. Is the PDF service running?");
                return;
            }

            PrintClickReturnToExit();
            _ = ReadLine();
            signing.Dispose();
        }

        private static void Error(string value)
        {
            WriteLine(value);
            PrintClickReturnToExit();
            _ = ReadLine();
        }

        static async Task<byte[]> GetDocument()
        {
            const string resourcePath = "ViewDocWithPad.Mustermann_Test_Formfields.pdf";
            Stream stream = typeof(Program).Assembly.GetManifestResourceStream(resourcePath);
            MemoryStream mStream = new MemoryStream();
            await stream.CopyToAsync(mStream);
            byte[] document = mStream.ToArray();
            return document;
        }

        static void OnButtonEvent(object sender, ButtonEventArgs e)
        {
            if (ButtonKind.StartSignature == e.ButtonKind)
            {
                WriteLine("The start sign button was clicked.");
                PrintClickReturnToExit();
            }
        }
        static void PrintClickReturnToExit()
        => WriteLine("Click return to exit.");
    }
}
